@@ -19,6 +19,7 @@
 #  18-Feb-2021 jdw add TargerInteractionProvider()
 #  25-Jul-2021 jdw refactored with common provider api
 #  27-Jul-2021 jdw add exclusion filter for testing
+#   3-Aug-2021 jdw add backup options for nonbuildable providers
 ##
 ##
 """
@@ -55,6 +56,7 @@ from rcsb.utils.dictionary.DictionaryApiProviderWrapper import DictionaryApiProv
 from rcsb.utils.dictionary.DictMethodCommonUtils import DictMethodCommonUtils
 from rcsb.utils.dictionary.NeighborInteractionProvider import NeighborInteractionProvider
 from rcsb.utils.ec.EnzymeDatabaseProvider import EnzymeDatabaseProvider
+from rcsb.utils.io.FileUtil import FileUtil
 from rcsb.utils.io.SingletonClass import SingletonClass
 
 # ---
@@ -405,6 +407,7 @@ class DictMethodResourceProvider(SingletonClass):
             remotePrefix (str, optional): remote prefix for a multi-channel stash rotation. Defaults to None.
             providerSelect (str, optional): select buildable|nonbuildable|None. Defaults to None
             cacheInstance (bool, optional): hold a reference to the data for the cached provided. Defaults to False.
+            clearCache (bool, optional): clear the cache directory before rebuilding.
         Returns:
             bool: True for success or False otherwise
         """
@@ -415,7 +418,13 @@ class DictMethodResourceProvider(SingletonClass):
         #
         kwargs["cacheInstance"] = kwargs["cacheInstance"] if "cacheInstance" in kwargs else True
         providerSelect = kwargs.get("providerSelect", None)
+        clearCache = kwargs.get("clearCache", None)
         failList = []
+        #
+        if not useCache and clearCache:
+            fU = FileUtil()
+            fU.remove(self.__cachePath)
+        #
         for providerName in sorted(self.__providerD):
             if self.__providerTypeExclude and self.__providerTypeExclude in self.__providerD[providerName]["providerType"]:
                 logger.info("Provider excluded by filter %r", providerName)
@@ -568,11 +577,17 @@ class DictMethodResourceProvider(SingletonClass):
             except Exception as e:
                 logger.exception("Failing with %s", str(e))
         else:
+            doBackup = kwargs.get("doBackup", False)
             try:
                 prI = self.__providerD[providerName]["class"](cachePath=cachePath, useCache=useCache, **classArgs)
                 prI.restore(cfgOb, configName, remotePrefix=remotePrefix, useStash=self.__restoreUseStash, useGit=self.__restoreUseGit)
                 prI = self.__providerD[providerName]["class"](cachePath=cachePath, useCache=True, **classArgs)
                 ok = prI.testCache(minCount=minCount)
+                if ok and doBackup and isStashable:
+                    useGit = kwargs.get("useGit", False)
+                    useStash = kwargs.get("useStash", True)
+                    okB = prI.backup(cfgOb, configName, remotePrefix=remotePrefix, useStash=useStash, useGit=useGit)
+                    ok = ok and okB
             except Exception as e:
                 logger.exception("Failing with %s", str(e))
         #
@@ -657,7 +672,7 @@ class DictMethodResourceProvider(SingletonClass):
         return ok
 
     def syncCache(self, providerName, cfgOb, configName, cachePath, remotePrefix=None, sourceCache="stash"):
-        """Synchronize cache data for the input provider from the input source cache
+        """Synchronize cache data for the input provider from the input source cache to git stash storage
 
         Args:
             providerName (str): provider name
